@@ -64,8 +64,7 @@ public:
     */
   enum ResultCode {
     ResultCodeSuccess = 0, ///< Success
-    ResultCodeError, ///< An error occurred. Call lastErrorString() for the error message. This isn't very verbose because IncidenceChanger hasn't been refactored yet.
-    ResultCodeIncidenceChangerError ///< IncidenceChanger returned false and didn't even create the job. This error is temporary. IncidenceChanger needs to be refactored. TODO
+    ResultCodeError ///< An error occurred. Call lastErrorString() for the error message. This isn't very verbose because IncidenceChanger hasn't been refactored yet.
   };
 
   /**
@@ -94,7 +93,7 @@ public:
     *
     * @param oldItem item containing the payload before the change. Must be valid
     *        and contain an Incidence::Ptr payload.
-    * @param newitem item containing the new payload. Must be valid and contain
+    * @param newItem item containing the new payload. Must be valid and contain
     *        an Incidence::Ptr payload.
     * @param description text that can be used in the undo/redo menu item to describe the operation
     *        If empty, a default one will be provided.
@@ -128,7 +127,9 @@ public:
     * be undone calling undo() once.
     *
     * @param items The list of items to delete. All items must be valid.
-    * @param atomicOperation If != 0, specifies which group of changes thischange belongs to.
+    * @param description text that can be used in the undo/redo menu item to describe the operation
+    *        If empty, a default one will be provided.
+    * @param atomicOperationId If != 0, specifies which group of changes thischange belongs to.
     *        Will be useful for atomic undoing/redoing, not implemented yet.
     */
   void recordDeletions( const Akonadi::Item::List &items,
@@ -243,7 +244,6 @@ Q_SIGNALS:
   void changed();
 
 private:
-  void setEnabled( bool enabled ); // TODO: kill this ?
 
   friend class IncidenceChanger;
   friend class Entry;
