@@ -63,7 +63,6 @@ class KDatePickerPopup: public QMenu
        @param items List of all desirable items, separated with a bitwise OR.
        @param date Initial date of datepicker-widget.
        @param parent The object's parent.
-       @param name The object's name.
     */
     explicit KDatePickerPopup( Items items = DatePicker,
                                const QDate &date = QDate::currentDate(),
@@ -92,6 +91,7 @@ class KDatePickerPopup: public QMenu
     /**
       This signal emits the new date (selected with datepicker or other
       menu-items).
+      @param date changed date
     */
     void dateChanged ( const QDate &date );
 
