@@ -44,12 +44,13 @@
 #include "entitydeletedattribute.h"
 #include "recentcollectionaction_p.h"
 
+#include <KIcon>
 #include <KAction>
 #include <KActionCollection>
 #include <KActionMenu>
 #include <KDebug>
 #include <KInputDialog>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMenu>
 #include <KMessageBox>
 #include <KToggleAction>
@@ -58,6 +59,7 @@
 #include <QApplication>
 #include <QClipboard>
 #include <QItemSelectionModel>
+#include <QPointer>
 #include <QWeakPointer>
 
 #include <boost/static_assert.hpp>
@@ -132,7 +134,8 @@ static bool canCreateCollection( const Akonadi::Collection &collection )
   if ( !( collection.rights() & Akonadi::Collection::CanCreateCollection ) )
     return false;
 
-  if ( !collection.contentMimeTypes().contains( Akonadi::Collection::mimeType() ) )
+  if ( !collection.contentMimeTypes().contains( Akonadi::Collection::mimeType() ) &&
+       !collection.contentMimeTypes().contains( Akonadi::Collection::virtualMimeType() ) )
     return false;
 
   return true;
@@ -796,7 +799,10 @@ class StandardActionManager::Private
     {
       Akonadi::AgentInstance instance = Akonadi::AgentManager::self()->instance( collection.resource() );
       if ( !instance.isOnline() ) {
-        if ( KMessageBox::questionYesNo( parentWidget, i18n( "Before syncing folder \"%1\" it is necessary to have the resource online. Do you want to make it online?" , collection.name()  ), i18n( "Account \"%1\" is offline", instance.name() ) ) != KMessageBox::Yes )
+        if ( KMessageBox::questionYesNo( parentWidget,
+                                         i18n( "Before syncing folder \"%1\" it is necessary to have the resource online. Do you want to make it online?", collection.displayName() ),
+                                         i18n( "Account \"%1\" is offline", instance.name() ),
+                                         KGuiItem( i18nc( "@action:button", "Go Online" ) ), KStandardGuiItem::cancel() ) != KMessageBox::Yes )
           return false;
         instance.setIsOnline( true );
       }
@@ -833,11 +839,8 @@ class StandardActionManager::Private
       const Collection collection = index.data( CollectionModel::CollectionRole ).value<Collection>();
       Q_ASSERT( collection.isValid() );
 
-      const QString displayName = collection.hasAttribute<EntityDisplayAttribute>() ? collection.attribute<EntityDisplayAttribute>()->displayName()
-                                                                                    : collection.name();
-
       CollectionPropertiesDialog* dlg = new CollectionPropertiesDialog( collection, mCollectionPropertiesPageNames, parentWidget );
-      dlg->setCaption( contextText( StandardActionManager::CollectionProperties, StandardActionManager::DialogTitle,displayName ) );
+      dlg->setCaption( contextText( StandardActionManager::CollectionProperties, StandardActionManager::DialogTitle, collection.displayName() ) );
       dlg->show();
     }
 
@@ -964,13 +967,12 @@ class StandardActionManager::Private
       const Collection collection = index.data( CollectionModel::CollectionRole ).value<Collection>();
       Q_ASSERT( collection.isValid() );
 
-      const QString displayName = collection.hasAttribute<EntityDisplayAttribute>() ? collection.attribute<EntityDisplayAttribute>()->displayName() : collection.name();
-
-      RenameFavoriteDialog dlg(contextText( StandardActionManager::RenameFavoriteCollection, StandardActionManager::DialogTitle ),contextText( StandardActionManager::RenameFavoriteCollection, StandardActionManager::DialogText ) , favoritesModel->favoriteLabel( collection ), displayName, parentWidget );
-      if ( dlg.exec() )
+      QPointer<RenameFavoriteDialog> dlg( new RenameFavoriteDialog(contextText( StandardActionManager::RenameFavoriteCollection, StandardActionManager::DialogTitle ),contextText( StandardActionManager::RenameFavoriteCollection, StandardActionManager::DialogText ) , favoritesModel->favoriteLabel( collection ), collection.displayName(), parentWidget) );
+      if ( dlg->exec() == QDialog::Accepted && dlg != 0 )
       {
-        favoritesModel->setFavoriteLabel( collection, dlg.newName() );
+        favoritesModel->setFavoriteLabel( collection, dlg->newName() );
       }
+      delete dlg;
     }
 
     void slotSynchronizeFavoriteCollections()
@@ -1059,17 +1061,17 @@ class StandardActionManager::Private
 
     void slotCreateResource()
     {
-      Akonadi::AgentTypeDialog dlg( parentWidget );
-      dlg.setCaption( contextText( StandardActionManager::CreateResource, StandardActionManager::DialogTitle ) );
+      QPointer<Akonadi::AgentTypeDialog> dlg( new Akonadi::AgentTypeDialog( parentWidget ) );
+      dlg->setCaption( contextText( StandardActionManager::CreateResource, StandardActionManager::DialogTitle ) );
 
       foreach ( const QString &mimeType, mMimeTypeFilter )
-        dlg.agentFilterProxyModel()->addMimeTypeFilter( mimeType );
+        dlg->agentFilterProxyModel()->addMimeTypeFilter( mimeType );
 
       foreach ( const QString &capability, mCapabilityFilter )
-        dlg.agentFilterProxyModel()->addCapabilityFilter( capability );
+        dlg->agentFilterProxyModel()->addCapabilityFilter( capability );
 
-      if ( dlg.exec() ) {
-        const AgentType agentType = dlg.agentType();
+      if ( dlg->exec() == QDialog::Accepted && dlg != 0 ) {
+        const AgentType agentType = dlg->agentType();
 
         if ( agentType.isValid() ) {
           AgentInstanceCreateJob *job = new AgentInstanceCreateJob( agentType, q );
@@ -1078,6 +1080,7 @@ class StandardActionManager::Private
           job->start();
         }
       }
+      delete dlg;
     }
 
     void slotDeleteResource()
@@ -1131,16 +1134,16 @@ class StandardActionManager::Private
     {
       const QSet<QString> mimeTypes = mimeTypesOfSelection( type );
 
-      CollectionDialog dlg( const_cast<QAbstractItemModel*>( model ) );
-      dlg.setMimeTypeFilter( mimeTypes.toList() );
+      QPointer<CollectionDialog> dlg( new CollectionDialog( const_cast<QAbstractItemModel*>( model ) ) );
+      dlg->setMimeTypeFilter( mimeTypes.toList() );
 
       if ( type == CopyItemToMenu || type == MoveItemToMenu )
-        dlg.setAccessRightsFilter( Collection::CanCreateItem );
+        dlg->setAccessRightsFilter( Collection::CanCreateItem );
       else if ( type == CopyCollectionToMenu || type == MoveCollectionToMenu )
-        dlg.setAccessRightsFilter( Collection::CanCreateCollection );
+        dlg->setAccessRightsFilter( Collection::CanCreateCollection );
 
-      if ( dlg.exec() ) {
-        const QModelIndex index = EntityTreeModel::modelIndexForCollection( collectionSelectionModel->model(), dlg.selectedCollection() );
+      if ( dlg->exec() == QDialog::Accepted && dlg != 0 ) {
+        const QModelIndex index = EntityTreeModel::modelIndexForCollection( collectionSelectionModel->model(), dlg->selectedCollection() );
         if ( !index.isValid() )
           return;
 
@@ -1149,6 +1152,7 @@ class StandardActionManager::Private
         QAbstractItemModel *model = const_cast<QAbstractItemModel *>( index.model() );
         model->dropMimeData( mimeData, dropAction, -1, -1, index );
       }
+      delete dlg;
     }
 
     void pasteTo( QItemSelectionModel *selectionModel, QAction *action, Qt::DropAction dropAction )
@@ -1289,7 +1293,7 @@ class StandardActionManager::Private
       const bool canCreateNewItems = (collection.rights() & Collection::CanCreateItem);
 
       const bool canCreateNewCollections = (collection.rights() & Collection::CanCreateCollection);
-      const bool canContainCollections = collection.contentMimeTypes().contains( Collection::mimeType() );
+      const bool canContainCollections = collection.contentMimeTypes().contains( Collection::mimeType() ) || collection.contentMimeTypes().contains( Collection::virtualMimeType() );
       const bool resourceAllowsRequiredMimeTypes = AgentManager::self()->instance( collection.resource() ).type().mimeTypes().toSet().contains( mimeTypes );
 
       const bool isReadOnlyForItems = (isItemAction && (!canCreateNewItems || !canContainRequiredMimeTypes));
@@ -1422,7 +1426,7 @@ class StandardActionManager::Private
       KLocalizedString text = contextTexts[ type ].value( context ).localizedText;
       if ( text.isEmpty() )
         return contextTexts[ type ].value( context ).text;
- 
+
       return text.subs( value ).toString();
     }
 
