@@ -37,8 +37,10 @@
 
 #include <KMimeType>
 #include <KTemporaryFile>
+#include <KDebug>
 
 #include <QTextDocument> // for Qt::escape() and Qt::mightBeRichText()
+#include <QTime>
 
 using namespace KCalCore;
 
@@ -62,6 +64,7 @@ class KCalCore::Incidence::Private
         mGeoLatitude( INVALID_LATLON ),
         mGeoLongitude( INVALID_LATLON ),
         mHasGeo( false ),
+        mThisAndFuture( false ),
         mLocalOnly( false )
     {
     }
@@ -88,6 +91,7 @@ class KCalCore::Incidence::Private
         mGeoLongitude( p.mGeoLongitude ),
         mHasGeo( p.mHasGeo ),
         mRecurrenceId( p.mRecurrenceId ),
+        mThisAndFuture( p.mThisAndFuture ),
         mLocalOnly( false )
     {
     }
@@ -118,6 +122,7 @@ class KCalCore::Incidence::Private
       mGeoLongitude = src.d->mGeoLongitude;
       mHasGeo = src.d->mHasGeo;
       mRecurrenceId = src.d->mRecurrenceId;
+      mThisAndFuture = src.d->mThisAndFuture;
       mLocalOnly = src.d->mLocalOnly;
 
       // Alarms and Attachments are stored in ListBase<...>, which is a QValueList<...*>.
@@ -168,6 +173,7 @@ class KCalCore::Incidence::Private
     bool mHasGeo;                       // if incidence has geo data
     QHash<Attachment::Ptr,QString> mTempFiles; // Temporary files for writing attachments to.
     KDateTime mRecurrenceId;            // recurrenceId
+    bool mThisAndFuture;
     bool mLocalOnly;                    // allow changes that won't go to the server
 };
 //@endcond
@@ -285,7 +291,17 @@ bool Incidence::equals( const IncidenceBase &incidence ) const
     secrecy() == i2->secrecy() &&
     priority() == i2->priority() &&
     stringCompare( location(), i2->location() ) &&
-    stringCompare( schedulingID(), i2->schedulingID() );
+    stringCompare( schedulingID(), i2->schedulingID() ) &&
+    recurrenceId() == i2->recurrenceId() &&
+    thisAndFuture() == i2->thisAndFuture();
+}
+
+QString Incidence::instanceIdentifier() const
+{
+  if ( hasRecurrenceId() ) {
+    return uid() + recurrenceId().toString();
+  }
+  return uid();
 }
 
 void Incidence::recreate()
@@ -377,7 +393,6 @@ void Incidence::setDtStart( const KDateTime &dt )
 {
   if ( d->mRecurrence ) {
     d->mRecurrence->setStartDateTime( dt );
-    d->mRecurrence->setAllDay( allDay() );
   }
   IncidenceBase::setDtStart( dt );
 }
@@ -536,7 +551,7 @@ Recurrence *Incidence::recurrence() const
 {
   if ( !d->mRecurrence ) {
     d->mRecurrence = new Recurrence();
-    d->mRecurrence->setStartDateTime( IncidenceBase::dtStart() );
+    d->mRecurrence->setStartDateTime( dateTime( RoleRecurrenceStart ) );
     d->mRecurrence->setAllDay( allDay() );
     d->mRecurrence->setRecurReadOnly( mReadOnly );
     d->mRecurrence->addObserver( const_cast<KCalCore::Incidence*>( this ) );
@@ -1025,6 +1040,16 @@ KDateTime Incidence::recurrenceId() const
   return d->mRecurrenceId;
 }
 
+void Incidence::setThisAndFuture( bool thisAndFuture )
+{
+  d->mThisAndFuture = thisAndFuture;
+}
+
+bool Incidence::thisAndFuture() const
+{
+  return d->mThisAndFuture;
+}
+
 void Incidence::setRecurrenceId( const KDateTime &recurrenceId )
 {
   if ( !mReadOnly ) {
